@@ -18,7 +18,17 @@ class DuplicateJSONFile(ConfigurationPandaError):
     """
     pass
 
-class InvalidClientInput(ConfigurationPandaError):
+
+class ExistingEnvironmentVariable(ConfigurationPandaError):
+    """
+    Error to raise when an existing environment variable prevents a
+    program operation from succeeding.
+
+    """
+    pass
+
+
+class InvalidParameter(ConfigurationPandaError):
     """
     Error to raise when an error arises from the use of invalid
     input provided by the client.
